@@ -1,6 +1,7 @@
 from collections import OrderedDict
 
 import nlp2
+from tqdm import tqdm
 
 
 def tok_begin(tokenizer):
@@ -18,7 +19,7 @@ def tok_mask(tokenizer):
 def get_topP_unk_token(tokenizer, file_paths: list, topP: float):
     unk_count_dict = OrderedDict()
     for path in file_paths:
-        for input_sent in nlp2.read_files_yield_lines(path):
+        for input_sent in tqdm(nlp2.read_files_yield_lines(path)):
             for tok in nlp2.split_sentence_to_array(input_sent):
                 if tokenizer._unk_token in tokenizer.tokenize(tok):
                     unk_count_dict[tok] = unk_count_dict.get(tok, 0) + 1
